`ensembleObsLabels` <-
function (x) 
UseMethod("ensembleObsLabels")

